@@ -13,6 +13,7 @@ pub mod details;
 pub mod response;
 
 pub use category::Category;
+use url::ParseError;
 
 pub use response::{NekosBestResponse, NekosBestResponseSingle};
 
@@ -26,10 +27,16 @@ pub enum NekosBestError {
 
     #[error("decoding")]
     Decoding(#[from] serde_json::Error),
+
+    #[error("decoding header values")]
+    DecodingHeader(#[from] HeaderDeserializeUrlEncodedError),
+
+    #[error("error parsing url")]
+    UrlParseError(#[from] ParseError),
 }
 
-pub const API_VERSION: usize = 1;
-pub const BASE_URL: &str = "https://nekos.best/api/v1";
+pub const API_VERSION: usize = 2;
+pub const BASE_URL: &str = "https://nekos.best/api/v2";
 
 #[cfg(feature = "strong-types")]
 pub mod strong_types;
@@ -76,9 +83,9 @@ mod test {
             &client,
             try_endpoint,
             [
-                Baka, Cry, Cuddle, Dance, Feed, Hug, Kiss, Laugh, Nekos, Pat, Poke, Slap, Smile,
-                Smug, Tickle, Wave, Bite, Blush, Bored, Facepalm, Happy, Highfive, Pout, Shrug, Sleep, Stare,
-                Think, ThumbsUp, Wink,
+                Baka, Cry, Cuddle, Dance, Feed, Hug, Kiss, Laugh, Neko, Pat, Poke, Slap, Smile,
+                Smug, Tickle, Wave, Bite, Blush, Bored, Facepalm, Happy, Highfive, Pout, Shrug,
+                Sleep, Stare, Think, ThumbsUp, Wink, Kitsune
             ]
         );
     }
@@ -102,9 +109,9 @@ mod test {
         }
 
         const KNOWN_ENDPOINTS: &[&str] = &known_image_endpoints!([
-            Baka, Cry, Cuddle, Dance, Feed, Hug, Kiss, Laugh, Nekos, Pat, Poke, Slap, Smile, Smug,
-            Tickle, Wave, Bite, Blush, Bored, Facepalm, Happy, Highfive, Pout, Shrug, Sleep, Stare, Think,
-            ThumbsUp, Wink,
+            Baka, Cry, Cuddle, Dance, Feed, Hug, Kiss, Laugh, Neko, Pat, Poke, Slap, Smile, Smug,
+            Tickle, Wave, Bite, Blush, Bored, Facepalm, Happy, Highfive, Pout, Shrug, Sleep, Stare,
+            Think, ThumbsUp, Wink, Kitsune
         ]);
 
         async fn get_endpoints(client: &reqwest::Client) -> HashMap<String, EndpointDesc> {
